@@ -47,15 +47,20 @@ MUON_BACKEND_PLUGIN(KNSBackend)
 
 QSharedPointer<Attica::ProviderManager> KNSBackend::m_atticaManager;
 
-void KNSBackend::initManager(KConfigGroup& group)
+void KNSBackend::initManager(const QUrl& entry)
 {
+    bool loadNeeded = false;
     if(!m_atticaManager) {
         m_atticaManager = QSharedPointer<Attica::ProviderManager>(new Attica::ProviderManager);
-        QUrl entry(group.readEntry("ProvidersUrl", QString()));
-        if(!m_atticaManager->defaultProviderFiles().contains(entry))
-            m_atticaManager->addProviderFileToDefaultProviders(entry);
-        m_atticaManager->loadDefaultProviders();
+        loadNeeded = true;
     }
+    if(!m_atticaManager->defaultProviderFiles().contains(entry)) {
+        m_atticaManager->addProviderFileToDefaultProviders(entry);
+        loadNeeded = true;
+    }
+
+    if(loadNeeded)
+        m_atticaManager->loadDefaultProviders();
 }
 
 KNSBackend::KNSBackend(QObject* parent)
@@ -70,6 +75,13 @@ KNSBackend::KNSBackend(QObject* parent)
 KNSBackend::~KNSBackend()
 {}
 
+void KNSBackend::markInvalid()
+{
+    qWarning() << "invalid kns backend!";
+    m_isValid = false;
+    setFetching(false);
+}
+
 void KNSBackend::setMetaData(const QString& path)
 {
     KDesktopFile cfg(path);
@@ -86,7 +98,7 @@ void KNSBackend::setMetaData(const QString& path)
     }
 
     if (m_name.isEmpty()) {
-        m_isValid = false;
+        markInvalid();
         qWarning() << "Couldn't find knsrc file" << knsrc;
         return;
     }
@@ -97,13 +109,13 @@ void KNSBackend::setMetaData(const QString& path)
         group = conf.group("KNewStuff3");
 
     if (!group.isValid()) {
-        m_isValid = false;
+        markInvalid();
         qWarning() << "Config group not found! Check your KNS3 installation.";
         return;
     }
 
     QStringList cats = group.readEntry("Categories", QStringList());
-    initManager(group);
+    initManager(QUrl(group.readEntry("ProvidersUrl", QString())));
     connect(m_atticaManager.data(), &Attica::ProviderManager::defaultProvidersLoaded, this, &KNSBackend::startFetchingCategories);
 
     foreach(const QString& c, cats) {
@@ -114,6 +126,7 @@ void KNSBackend::setMetaData(const QString& path)
     connect(m_manager, &KNS3::DownloadManager::searchResult, this, &KNSBackend::receivedEntries);
     connect(m_manager, &KNS3::DownloadManager::entryStatusChanged, this, &KNSBackend::statusChanged);
 
+    //otherwise this will be executed when defaultProvidersLoaded is emitted
     if (!m_atticaManager->providers().isEmpty()) {
         startFetchingCategories();
     }
@@ -136,8 +149,7 @@ void KNSBackend::startFetchingCategories()
 {
     if (m_atticaManager->providers().isEmpty()) {
         qWarning() << "no providers for" << m_name;
-        m_isValid = false;
-        setFetching(false);
+        markInvalid();
         return;
     }
 
@@ -177,8 +189,7 @@ void KNSBackend::categoriesLoaded(Attica::BaseJob* job)
             ++it;
     }
     if (m_categories.isEmpty()) {
-        m_isValid = false;
-        setFetching(false);
+        markInvalid();
         return;
     }
 
@@ -224,11 +235,7 @@ void KNSBackend::receivedEntries(const KNS3::Entry::List& entries)
     }
     
     foreach(const KNS3::Entry& entry, entries) {
-        KNSResource* r = qobject_cast<KNSResource*>(m_resourcesByName.value(entry.id()));
-        if (r) {
-            r->setEntry(entry);
-        } else
-            qWarning() << "Couldn't find a resource for" << entry.id() << entry.name();
+        statusChanged(entry);
     }
     ++m_page;
     m_manager->search(m_page);
@@ -272,7 +279,7 @@ void KNSBackend::installApplication(AbstractResource* app)
     transModel->removeTransaction(t);
 }
 
-void KNSBackend::installApplication(AbstractResource* app, AddonList)
+void KNSBackend::installApplication(AbstractResource* app, const AddonList&)
 {
     installApplication(app);
 }
