@@ -53,7 +53,7 @@ public:
     virtual void cancelTransaction(AbstractResource* app) override;
     virtual void removeApplication(AbstractResource* app) override;
     virtual void installApplication(AbstractResource* app) override;
-    virtual void installApplication(AbstractResource* app, AddonList addons) override;
+    virtual void installApplication(AbstractResource* app, const AddonList& addons) override;
     virtual AbstractResource* resourceByPackageName(const QString& name) const override;
     virtual int updatesCount() const override;
     virtual AbstractReviewsBackend* reviewsBackend() const override;
@@ -75,21 +75,22 @@ public Q_SLOTS:
     void statusChanged(const KNS3::Entry& entry);
 
 private:
-    static void initManager(KConfigGroup& group);
+    static void initManager(const QUrl& group);
     static QSharedPointer<Attica::ProviderManager> m_atticaManager;
     void setFetching(bool f);
+    void markInvalid();
     
     bool m_fetching;
     bool m_isValid;
     KNS3::DownloadManager* m_manager;
     QHash<QString, AbstractResource*> m_resourcesByName;
     int m_page;
-    KNSReviews* m_reviews;
+    KNSReviews* const m_reviews;
     Attica::Provider m_provider;
     QMap<QString, Attica::Category> m_categories;
     QString m_name;
     QString m_iconName;
-    AbstractBackendUpdater* m_updater;
+    AbstractBackendUpdater* const m_updater;
 };
 
 #endif // KNSBACKEND_H
