@@ -31,6 +31,7 @@
 #include <AppstreamQt/database.h>
 #include <functional>
 
+class AppPackageKitResource;
 class PackageKitUpdater;
 class PKTransaction;
 
@@ -50,7 +51,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         virtual int updatesCount() const override;
         
         virtual void installApplication(AbstractResource* app) override;
-        virtual void installApplication(AbstractResource* app, AddonList addons) override;
+        virtual void installApplication(AbstractResource* app, const AddonList& addons) override;
         virtual void removeApplication(AbstractResource* app) override;
         virtual void cancelTransaction(AbstractResource* app) override;
         virtual bool isValid() const override { return true; }
@@ -61,6 +62,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         bool isPackageNameUpgradeable(const PackageKitResource* res) const;
         QString upgradeablePackageId(const PackageKitResource* res) const;
         QVector<AbstractResource*> resourcesByPackageName(const QString& name, bool updating) const;
+        QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
 
     public Q_SLOTS:
         void transactionCanceled(Transaction* t);
@@ -83,8 +85,6 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         void fetchUpdates();
         void acquireFetching(bool f);
 
-        QHash<QString, AbstractResource*> m_packages;
-        QHash<QString, AbstractResource*> m_updatingPackages;
         Appstream::Database m_appdata;
         QList<Transaction*> m_transactions;
         PackageKitUpdater* m_updater;
@@ -92,8 +92,15 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         int m_isFetching;
         QSet<QString> m_updatesPackageId;
         QList<QAction*> m_messageActions;
-        QHash<QString, QStringList> m_translationPackageToApp;
-        QHash<QString, QStringList> m_updatingTranslationPackageToApp;
+
+        struct Packages {
+            QHash<QString, AbstractResource*> packages;
+            QHash<QString, QStringList> packageToApp;
+            QHash<QString, QVector<AppPackageKitResource*>> extendedBy;
+        };
+
+        Packages m_packages;
+        Packages m_updatingPackages;
 };
 
 #endif // PACKAGEKITBACKEND_H
