@@ -52,7 +52,7 @@ class PackageKitUpdater : public AbstractBackendUpdater
         virtual QString statusDetail() const override;
         virtual quint64 downloadSpeed() const override;
 
-        /** in muon-updater, actions with HighPriority will be shown in a KMessageWidget,
+        /** in plasma-discover-updater, actions with HighPriority will be shown in a KMessageWidget,
          *  normal priority will go right on top of the more menu, low priority will go
          *  to the advanced menu
          */
@@ -76,6 +76,7 @@ class PackageKitUpdater : public AbstractBackendUpdater
         void percentageChanged();
         
     private:
+        void itemProgress(const QString &itemID, PackageKit::Transaction::Status status, uint percentage);
         void fetchLastUpdateTime();
         void lastUpdateTimeReceived(QDBusPendingCallWatcher* w);
         void setProgressing(bool progressing);
