@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
+ *   Copyright ?? 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
  *   modify it under the terms of the GNU General Public License as        *
@@ -35,6 +35,7 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QAbstractListModel
     Q_OBJECT
     Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
     Q_PROPERTY(bool isFetching READ isFetching NOTIFY fetchingChanged)
+    Q_PROPERTY(QVariantList messageActions READ messageActionsVariant NOTIFY fetchingChanged)
     public:
         enum Roles {
             NameRole = Qt::UserRole,
@@ -74,16 +75,17 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QAbstractListModel
         
         Q_SCRIPTABLE AbstractResource* resourceByPackageName(const QString& name);
 
-        void integrateMainWindow(KXmlGuiWindow* w);
+        void integrateActions(KActionCollection* w);
         
         bool isBusy() const;
         bool isFetching() const;
         QList<QAction*> messageActions() const;
+        QVariantList messageActionsVariant() const;
         
         virtual QHash<int, QByteArray> roleNames() const override;
 
     public Q_SLOTS:
-        void installApplication(AbstractResource* app, AddonList addons);
+        void installApplication(AbstractResource* app, const AddonList& addons);
         void installApplication(AbstractResource* app);
         void removeApplication(AbstractResource* app);
         void cancelTransaction(AbstractResource* app);
@@ -115,7 +117,7 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QAbstractListModel
         QVector< AbstractResourcesBackend* > m_backends;
         QVector< QVector<AbstractResource*> > m_resources;
         int m_initializingBackends;
-        KXmlGuiWindow* m_mainwindow;
+        KActionCollection* m_actionCollection;
         const QHash<int, QByteArray> m_roles;
 
         static ResourcesModel* s_self;
